lkml.org 
[lkml]   [2004]   [Feb]   [20]   [last100]   RSS Feed
Views: [wrap][no wrap]   [headers]  [forward] 
 
Messages in this thread
Patch in this message
/
Subject[PATCH] ppc32: rework l2 cache code
From
Date
Hi !

This patch removes the code that tweaked the L1 cache when setting
up the L2 one. That was added a while ago in the intend of making
things more robust but ended up breaking earlier 750 CPU setup.

Also fix some crap in the L1 cache code that is only used for the
powermac sleep at this point.

Please apply.

Ben.

diff -urN linux-2.5/arch/ppc/kernel/l2cr.S linuxppc-2.5-benh/arch/ppc/kernel/l2cr.S
--- linux-2.5/arch/ppc/kernel/l2cr.S 2004-02-20 11:26:06.000000000 +1100
+++ linuxppc-2.5-benh/arch/ppc/kernel/l2cr.S 2004-02-21 12:30:29.000000000 +1100
@@ -130,11 +130,6 @@
mtspr HID0,r4 /* Disable DPM */
sync

- /* Flush & disable L1 */
- mr r5,r3
- bl __flush_disable_L1
- mr r3,r5
-
/* Get the current enable bit of the L2CR into r4 */
mfspr r4,L2CR

@@ -236,7 +231,6 @@
sync

4:
- bl __inval_enable_L1

/* Restore HID0[DPM] to whatever it was before */
sync
@@ -394,11 +388,10 @@
END_FTR_SECTION_IFSET(CPU_FTR_ALTIVEC)
sync

/* Load counter to 0x1000 cache lines (128k) and
* load cache with datas
*/
- lis r3,0x0002
-// li r3,0x1000 /* 128kB / 32B */
+ li r3,0x4000 /* 512kB / 32B */
mtctr r3
li r3, 0
1:
@@ -409,8 +402,7 @@
sync

/* Now flush those cache lines */
- lis r3,0x0002
-// li r3,0x1000 /* 128kB / 32B */
+ li r3,0x4000 /* 512kB / 32B */
mtctr r3
li r3, 0
1:

-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@vger.kernel.org
More majordomo info at http://vger.kernel.org/majordomo-info.html
@@ -394,11 +388,10 @@
sync

- /* Load counter to 0x1000 cache lines (128k) and
+ /* Load counter to 0x4000 cache lines (512k) and
* load cache with datas
*/
Please read the FAQ at http://www.tux.org/lkml/

\
 
 \ /
  Last update: 2005-03-22 14:01    [W:0.027 / U:1.724 seconds]
©2003-2020 Jasper Spaans|hosted at Digital Ocean and TransIP|Read the blog|Advertise on this site